==> common-17.2.0-sources.jar: com/microsoft/identity/common/internal/fido/IFidoManager.kt <==
// Copyright (c) Microsoft Corporation.
// All rights reserved.
//
// This code is licensed under the MIT License.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files(the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions :
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
package com.microsoft.identity.common.internal.fido

/**
 * Representation of a manager that handles interactions with a passkey provider (usually through an API).
 */
interface IFidoManager {
    /**
     * Interacts with the FIDO credential provider and returns an assertion.
     * @param challenge
     * @param relyingPartyIdentifier
     * @param allowedCredentials
     * @param userVerificationPolicy
     * @return assertion
     * @throws Exception
     */
    suspend fun authenticate(challenge: String,
                             relyingPartyIdentifier: String,
                             allowedCredentials: List<String>?,
                             userVerificationPolicy: String): String
}

==> common-18.2.3-sources.jar: com/microsoft/identity/common/internal/fido/IFidoManager.kt <==
// Copyright (c) Microsoft Corporation.
// All rights reserved.
//
// This code is licensed under the MIT License.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files(the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions :
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
package com.microsoft.identity.common.internal.fido

import io.opentelemetry.api.trace.Span

/**
 * Representation of a manager that handles interactions with a passkey provider (usually through an API).
 */
interface IFidoManager {
    /**
     * Interacts with the FIDO credential provider and returns an assertion.
     * @param challenge
     * @param relyingPartyIdentifier
     * @param allowedCredentials
     * @param userVerificationPolicy
     * @param span
     * @return assertion
     * @throws Exception
     */
    suspend fun authenticate(challenge: String,
                             relyingPartyIdentifier: String,
                             allowedCredentials: List<String>?,
                             userVerificationPolicy: String,
                             span: Span) : String
}
